%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Name: GetBreakpoints.m        Created: 00/07/28    Revised: 01/09/06
%
% Usage: Extracts an optimal segmentation from probability arrays and
%        mask calculated with TriangleAlgPois.m.  
%        NOTE: Function is defined in an implicit manner.
%
% Inputs:  bp := vector of breakpoints (i.e., those calculated so far
%                in moving through the array).
%          i := index of lefthand side of subinterval of x
%               for which probabilities are to be compared
%          j := index of righthand side of subinterval of x
%               for which probabilities are to be compared
%          t0 := triangular array of probability values under null
%                hypothesis (i.e., homogeneity)
%          t1 := triangular array of probability values under alternative
%                hypothesis (i.e., inhomogeneity).
%          mm := mask indicating (with a '1') the decided split locations
%		 in the sequence (in relation to the arrays t0, t1).
%
% Output:  bp := vector of breakpoints (i.e., including those just
%                calculated).
%
% Calls:  Only internal Matlab functions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function bp = GetBreakpoints(bp,i,j,t0,t1,mm)

if t0(i,j) < t1(i,j),

   bp = [bp mm(i,j)];
   bp = GetBreakpoints(bp,i,mm(i,j),t0,t1,mm);
   bp = GetBreakpoints(bp,mm(i,j)+1,j,t0,t1,mm);

end

%  This code has been developed by Eric Kolaczyk and Robert Nowak.
%  Copyright (c) Eric Kolaczyk and Robert Nowak, 2000.
%  All rights reserved.
