%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Name: log_bi_calc.m		Created: 00/07/24    Revised: 01/09/06
%
% Usage: Utility function to comput log binomial probability under
%        homogeneity assumptions.
%
% Inputs:  x := vector of independent Poisson counts (n x 1),
%              where n need not be a power of 2.
%          i := index of lefthand side of subinterval of x
%               for which probability is to be computed
%          j := index of righthand side of subinterval of x
%               for which probability is to be computed
%
% Output:  p := log binomial probability
%
% Calls:  Only internal Matlab functions.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function p = log_bi_calc(x,i,j);

s0 = sum(x(i:j));
s1 = sum(x(i+1:j));

r = (j-i)/(j-i+1);
p = gammaln(s0+1)-(gammaln(s0-s1+1)+gammaln(s1+1))+ s1.*log(r)+ ...
						 (s0-s1).*log(1-r);

%  This code has been developed by Eric Kolaczyk and Robert Nowak.
%  Copyright (c) Eric Kolaczyk and Robert Nowak, 2000.
%  All rights reserved.
